@@ -5,7 +5,7 @@ except ImportError:
 
 from elasticsearch_raven import configuration
 from elasticsearch_raven import transport
-from elasticsearch_raven.udp_server import Sender
+from elasticsearch_raven.queue_sender import Sender
 
 
 class HttpUtils:
@@ -16,7 +16,7 @@ class HttpUtils:
     def start_sender(self):
         log_transport = transport.get_configured_log_transport()
         sender = Sender(log_transport, self._pending_logs,
-                        self._exception_queue).as_thread()
+                        self._exception_queue.put).as_thread()
         sender.start()
 
     def get_application(self):
@@ -35,5 +35,5 @@ class HttpUtils:
             status = '200 OK'
             response_headers = [('Content-Type', 'text/plain')]
             start_response(status, response_headers)
-            return [''.encode('utf-8')]
+            return [b'']
         return application
